summaryrefslogtreecommitdiffstats
path: root/libkdenetwork/libgpgme-copy/gpgme/rungpg.c
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /libkdenetwork/libgpgme-copy/gpgme/rungpg.c
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdenetwork/libgpgme-copy/gpgme/rungpg.c')
-rw-r--r--libkdenetwork/libgpgme-copy/gpgme/rungpg.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/libkdenetwork/libgpgme-copy/gpgme/rungpg.c b/libkdenetwork/libgpgme-copy/gpgme/rungpg.c
index d09cdf3b6..42fff0032 100644
--- a/libkdenetwork/libgpgme-copy/gpgme/rungpg.c
+++ b/libkdenetwork/libgpgme-copy/gpgme/rungpg.c
@@ -1211,7 +1211,7 @@ start (engine_gpg_t gpg)
int saved_errno;
int i, n;
int status;
- struct spawn_fd_item_s *fd_child_list, *fd_parent_list;
+ struct spawn_fd_item_s *fd_child_list, *fd_tqparent_list;
if (!gpg)
return gpg_error (GPG_ERR_INV_VALUE);
@@ -1247,7 +1247,7 @@ start (engine_gpg_t gpg)
fd_child_list = calloc (n + n, sizeof *fd_child_list);
if (!fd_child_list)
return gpg_error_from_errno (errno);
- fd_parent_list = fd_child_list + n;
+ fd_tqparent_list = fd_child_list + n;
/* build the fd list for the child */
n = 0;
@@ -1269,32 +1269,32 @@ start (engine_gpg_t gpg)
fd_child_list[n].fd = -1;
fd_child_list[n].dup_to = -1;
/* Build the fd list for the parent. */
n = 0;
if (gpg->status.fd[1] != -1)
{
- fd_parent_list[n].fd = gpg->status.fd[1];
- fd_parent_list[n].dup_to = -1;
+ fd_tqparent_list[n].fd = gpg->status.fd[1];
+ fd_tqparent_list[n].dup_to = -1;
n++;
}
if (gpg->colon.fd[1] != -1)
{
- fd_parent_list[n].fd = gpg->colon.fd[1];
- fd_parent_list[n].dup_to = -1;
+ fd_tqparent_list[n].fd = gpg->colon.fd[1];
+ fd_tqparent_list[n].dup_to = -1;
n++;
}
for (i = 0; gpg->fd_data_map[i].data; i++)
{
- fd_parent_list[n].fd = gpg->fd_data_map[i].peer_fd;
- fd_parent_list[n].dup_to = -1;
+ fd_tqparent_list[n].fd = gpg->fd_data_map[i].peer_fd;
+ fd_tqparent_list[n].dup_to = -1;
n++;
}
- fd_parent_list[n].fd = -1;
- fd_parent_list[n].dup_to = -1;
+ fd_tqparent_list[n].fd = -1;
+ fd_tqparent_list[n].dup_to = -1;
status = _gpgme_io_spawn (gpg->file_name ? gpg->file_name :
_gpgme_get_gpg_path (),
- gpg->argv, fd_child_list, fd_parent_list);
+ gpg->argv, fd_child_list, fd_tqparent_list);
saved_errno = errno;
free (fd_child_list);
if (status == -1)
@@ -1269,32 +1269,32 @@ start (engine_gpg_t gpg)
fd_child_list[n].fd = -1;
fd_child_list[n].dup_to = -1;
- /* Build the fd list for the parent. */
+ /* Build the fd list for the tqparent. */
n = 0;
if (gpg->status.fd[1] != -1)